@@ -68,8 +68,8 @@ SaveElementTreeNode = True
 
 
 class FooListSub(supermod.FooList):
-    def __init__(self, Foo=None, Bar=None, Baz=None, **kwargs_):
-        super(FooListSub, self).__init__(Foo, Bar, Baz,  **kwargs_)
+    def __init__(self, attribute01='0', attribute02='none', Foo=None, Bar=None, Baz=None, **kwargs_):
+        super(FooListSub, self).__init__(attribute01, attribute02, Foo, Bar, Baz,  **kwargs_)
 supermod.FooList.subclass = FooListSub
 # end class FooListSub
 
