@@ -3,7 +3,7 @@
 
 #
 # Generated  by generateDS.py.
-# Python 3.7.6 (default, Jan  8 2020, 19:59:22)  [GCC 7.3.0]
+# Python 3.7.7 (default, Mar 26 2020, 15:48:22)  [GCC 7.3.0]
 #
 # Command line options:
 #   ('--no-dates', '')
@@ -253,7 +253,12 @@ except ImportError as exp:
                     raise_parse_error(node, 'Requires sequence of float values')
             return values
         def gds_format_decimal(self, input_data, input_name=''):
-            return ('%s' % input_data).rstrip('0')
+            return_value = '%s' % input_data
+            if '.' in return_value:
+                return_value = return_value.rstrip('0')
+                if return_value.endswith('.'):
+                    return_value = return_value.rstrip('.')
+            return return_value
         def gds_parse_decimal(self, input_data, node=None, input_name=''):
             try:
                 decimal_value = decimal_.Decimal(input_data)
@@ -267,7 +272,7 @@ except ImportError as exp:
                 raise_parse_error(node, 'Requires decimal value')
             return value
         def gds_format_decimal_list(self, input_data, input_name=''):
-            return '%s' % ' '.join(input_data)
+            return ' '.join([self.gds_format_decimal(item) for item in input_data])
         def gds_validate_decimal_list(
                 self, input_data, node=None, input_name=''):
             values = input_data.split()
@@ -951,21 +956,36 @@ def _cast(typ, value):
 #
 
 
+class attribute02Type(str, Enum):
+    NONE='none'
+    OREGANO='oregano'
+    ROSEMARY='rosemary'
+    THYME='thyme'
+    SAGE='sage'
+    SUMAC='sumac'
+
+
 class FooList(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
+        MemberSpec_('attribute01', 'attribute01Type', 0, 1, {'use': 'optional'}),
+        MemberSpec_('attribute02', 'attribute02Type', 0, 1, {'use': 'optional'}),
         MemberSpec_('Foo', 'FooType', 0, 0, {'name': 'Foo', 'type': 'FooType'}, None),
         MemberSpec_('Bar', 'BarType', 0, 0, {'name': 'Bar', 'type': 'BarType'}, None),
         MemberSpec_('Baz', 'BazType', 0, 0, {'name': 'Baz', 'type': 'BazType'}, None),
     ]
     subclass = None
     superclass = None
-    def __init__(self, Foo=None, Bar=None, Baz=None, gds_collector_=None, **kwargs_):
+    def __init__(self, attribute01='0', attribute02='none', Foo=None, Bar=None, Baz=None, gds_collector_=None, **kwargs_):
         self.gds_collector_ = gds_collector_
         self.gds_elementtree_node_ = None
         self.original_tagname_ = None
         self.parent_object_ = kwargs_.get('parent_object_')
         self.ns_prefix_ = None
+        self.attribute01 = _cast(int, attribute01)
+        self.attribute01_nsprefix_ = None
+        self.attribute02 = _cast(None, attribute02)
+        self.attribute02_nsprefix_ = None
         self.Foo = Foo
         self.Foo_nsprefix_ = None
         self.Bar = Bar
@@ -999,6 +1019,42 @@ class FooList(GeneratedsSuper):
         return self.Baz
     def set_Baz(self, Baz):
         self.Baz = Baz
+    def get_attribute01(self):
+        return self.attribute01
+    def set_attribute01(self, attribute01):
+        self.attribute01 = attribute01
+    def get_attribute02(self):
+        return self.attribute02
+    def set_attribute02(self, attribute02):
+        self.attribute02 = attribute02
+    def validate_attribute01Type(self, value):
+        # Validate type attribute01Type, a restriction on xs:integer.
+        if value is not None and Validate_simpletypes_ and self.gds_collector_ is not None:
+            if not isinstance(value, int):
+                lineno = self.gds_get_node_lineno_()
+                self.gds_collector_.add_message('Value "%(value)s"%(lineno)s is not of the correct base simple type (int)' % {"value": value, "lineno": lineno, })
+                return False
+            if value < 0:
+                lineno = self.gds_get_node_lineno_()
+                self.gds_collector_.add_message('Value "%(value)s"%(lineno)s does not match xsd minInclusive restriction on attribute01Type' % {"value": value, "lineno": lineno} )
+                result = False
+            if value > 9:
+                lineno = self.gds_get_node_lineno_()
+                self.gds_collector_.add_message('Value "%(value)s"%(lineno)s does not match xsd maxInclusive restriction on attribute01Type' % {"value": value, "lineno": lineno} )
+                result = False
+    def validate_attribute02Type(self, value):
+        # Validate type attribute02Type, a restriction on xs:string.
+        if value is not None and Validate_simpletypes_ and self.gds_collector_ is not None:
+            if not isinstance(value, str):
+                lineno = self.gds_get_node_lineno_()
+                self.gds_collector_.add_message('Value "%(value)s"%(lineno)s is not of the correct base simple type (str)' % {"value": value, "lineno": lineno, })
+                return False
+            value = value
+            enumerations = ['none', 'oregano', 'rosemary', 'thyme', 'sage', 'sumac']
+            if value not in enumerations:
+                lineno = self.gds_get_node_lineno_()
+                self.gds_collector_.add_message('Value "%(value)s"%(lineno)s does not match xsd enumeration restriction on attribute02Type' % {"value" : encode_str_2_3(value), "lineno": lineno} )
+                result = False
     def hasContent_(self):
         if (
             self.Foo is not None or
@@ -1032,7 +1088,12 @@ class FooList(GeneratedsSuper):
         else:
             outfile.write('/>%s' % (eol_, ))
     def exportAttributes(self, outfile, level, already_processed, namespaceprefix_='', name_='FooList'):
-        pass
+        if self.attribute01 != 0 and 'attribute01' not in already_processed:
+            already_processed.add('attribute01')
+            outfile.write(' attribute01="%s"' % self.gds_format_integer(self.attribute01, input_name='attribute01'))
+        if self.attribute02 != "none" and 'attribute02' not in already_processed:
+            already_processed.add('attribute02')
+            outfile.write(' attribute02=%s' % (self.gds_encode(self.gds_format_string(quote_attrib(self.attribute02), input_name='attribute02')), ))
     def exportChildren(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='FooList', fromsubclass_=False, pretty_print=True):
         if pretty_print:
             eol_ = '\n'
@@ -1059,7 +1120,16 @@ class FooList(GeneratedsSuper):
             self.buildChildren(child, node, nodeName_, gds_collector_=gds_collector_)
         return self
     def buildAttributes(self, node, attrs, already_processed):
-        pass
+        value = find_attr_value_('attribute01', node)
+        if value is not None and 'attribute01' not in already_processed:
+            already_processed.add('attribute01')
+            self.attribute01 = self.gds_parse_integer(value, node, 'attribute01')
+            self.validate_attribute01Type(self.attribute01)    # validate type attribute01Type
+        value = find_attr_value_('attribute02', node)
+        if value is not None and 'attribute02' not in already_processed:
+            already_processed.add('attribute02')
+            self.attribute02 = value
+            self.validate_attribute02Type(self.attribute02)    # validate type attribute02Type
     def buildChildren(self, child_, node, nodeName_, fromsubclass_=False, gds_collector_=None):
         if nodeName_ == 'Foo':
             obj_ = FooType.factory(parent_object_=self)
