@@ -969,105 +969,116 @@ def _cast(typ, value):
 #
 
 
-class containerType(GeneratedsSuper):
+class valuesType(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
-        MemberSpec_('decimal01', 'xs:decimal', 0, 0, {'name': 'decimal01', 'type': 'xs:decimal'}, None),
-        MemberSpec_('decimal02', 'xs:decimal', 0, 0, {'name': 'decimal02', 'type': 'xs:decimal'}, None),
-        MemberSpec_('decimal03', 'xs:decimal', 0, 0, {'name': 'decimal03', 'type': 'xs:decimal'}, None),
+        MemberSpec_('value', 'xs:decimal', 1, 1, {'maxOccurs': 'unbounded', 'minOccurs': '0', 'name': 'value', 'type': 'xs:decimal'}, None),
+        MemberSpec_('valuelist', ['valuesListType', 'xs:decimal'], 1, 1, {'maxOccurs': 'unbounded', 'minOccurs': '0', 'name': 'valuelist', 'type': 'xs:decimal'}, None),
     ]
     subclass = None
     superclass = None
-    def __init__(self, decimal01=None, decimal02=None, decimal03=None, gds_collector_=None, **kwargs_):
+    def __init__(self, value=None, valuelist=None, gds_collector_=None, **kwargs_):
         self.gds_collector_ = gds_collector_
         self.gds_elementtree_node_ = None
         self.original_tagname_ = None
         self.parent_object_ = kwargs_.get('parent_object_')
         self.ns_prefix_ = None
-        self.decimal01 = decimal01
-        self.decimal01_nsprefix_ = None
-        self.decimal02 = decimal02
-        self.decimal02_nsprefix_ = None
-        self.decimal03 = decimal03
-        self.decimal03_nsprefix_ = None
+        if value is None:
+            self.value = []
+        else:
+            self.value = value
+        self.value_nsprefix_ = None
+        if valuelist is None:
+            self.valuelist = []
+        else:
+            self.valuelist = valuelist
+        self.valuelist_nsprefix_ = None
     def factory(*args_, **kwargs_):
         if CurrentSubclassModule_ is not None:
             subclass = getSubclassFromModule_(
-                CurrentSubclassModule_, containerType)
+                CurrentSubclassModule_, valuesType)
             if subclass is not None:
                 return subclass(*args_, **kwargs_)
-        if containerType.subclass:
-            return containerType.subclass(*args_, **kwargs_)
+        if valuesType.subclass:
+            return valuesType.subclass(*args_, **kwargs_)
         else:
-            return containerType(*args_, **kwargs_)
+            return valuesType(*args_, **kwargs_)
     factory = staticmethod(factory)
     def get_ns_prefix_(self):
         return self.ns_prefix_
     def set_ns_prefix_(self, ns_prefix):
         self.ns_prefix_ = ns_prefix
-    def get_decimal01(self):
-        return self.decimal01
-    def set_decimal01(self, decimal01):
-        self.decimal01 = decimal01
-    def get_decimal02(self):
-        return self.decimal02
-    def set_decimal02(self, decimal02):
-        self.decimal02 = decimal02
-    def get_decimal03(self):
-        return self.decimal03
-    def set_decimal03(self, decimal03):
-        self.decimal03 = decimal03
+    def get_value(self):
+        return self.value
+    def set_value(self, value):
+        self.value = value
+    def add_value(self, value):
+        self.value.append(value)
+    def insert_value_at(self, index, value):
+        self.value.insert(index, value)
+    def replace_value_at(self, index, value):
+        self.value[index] = value
+    def get_valuelist(self):
+        return self.valuelist
+    def set_valuelist(self, valuelist):
+        self.valuelist = valuelist
+    def add_valuelist(self, value):
+        self.valuelist.append(value)
+    def insert_valuelist_at(self, index, value):
+        self.valuelist.insert(index, value)
+    def replace_valuelist_at(self, index, value):
+        self.valuelist[index] = value
+    def validate_valuesListType(self, value):
+        result = True
+        # Validate type valuesListType, a restriction on xs:decimal.
+        pass
+        return result
     def hasContent_(self):
         if (
-            self.decimal01 is not None or
-            self.decimal02 is not None or
-            self.decimal03 is not None
+            self.value or
+            self.valuelist
         ):
             return True
         else:
             return False
-    def export(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='containerType', pretty_print=True):
-        imported_ns_def_ = GenerateDSNamespaceDefs_.get('containerType')
+    def export(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='valuesType', pretty_print=True):
+        imported_ns_def_ = GenerateDSNamespaceDefs_.get('valuesType')
         if imported_ns_def_ is not None:
             namespacedef_ = imported_ns_def_
         if pretty_print:
             eol_ = '\n'
         else:
             eol_ = ''
-        if self.original_tagname_ is not None and name_ == 'containerType':
+        if self.original_tagname_ is not None and name_ == 'valuesType':
             name_ = self.original_tagname_
         if UseCapturedNS_ and self.ns_prefix_:
             namespaceprefix_ = self.ns_prefix_ + ':'
         showIndent(outfile, level, pretty_print)
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
-        self.exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='containerType')
+        self.exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='valuesType')
         if self.hasContent_():
             outfile.write('>%s' % (eol_, ))
-            self.exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='containerType', pretty_print=pretty_print)
+            self.exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='valuesType', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
             outfile.write('</%s%s>%s' % (namespaceprefix_, name_, eol_))
         else:
             outfile.write('/>%s' % (eol_, ))
-    def exportAttributes(self, outfile, level, already_processed, namespaceprefix_='', name_='containerType'):
+    def exportAttributes(self, outfile, level, already_processed, namespaceprefix_='', name_='valuesType'):
         pass
-    def exportChildren(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='containerType', fromsubclass_=False, pretty_print=True):
+    def exportChildren(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='valuesType', fromsubclass_=False, pretty_print=True):
         if pretty_print:
             eol_ = '\n'
         else:
             eol_ = ''
-        if self.decimal01 is not None:
-            namespaceprefix_ = self.decimal01_nsprefix_ + ':' if (UseCapturedNS_ and self.decimal01_nsprefix_) else ''
+        for value_ in self.value:
+            namespaceprefix_ = self.value_nsprefix_ + ':' if (UseCapturedNS_ and self.value_nsprefix_) else ''
             showIndent(outfile, level, pretty_print)
-            outfile.write('<%sdecimal01>%s</%sdecimal01>%s' % (namespaceprefix_ , self.gds_format_decimal(self.decimal01, input_name='decimal01'), namespaceprefix_ , eol_))
-        if self.decimal02 is not None:
-            namespaceprefix_ = self.decimal02_nsprefix_ + ':' if (UseCapturedNS_ and self.decimal02_nsprefix_) else ''
+            outfile.write('<%svalue>%s</%svalue>%s' % (namespaceprefix_ , self.gds_format_decimal(value_, input_name='value'), namespaceprefix_ , eol_))
+        for valuelist_ in self.valuelist:
+            namespaceprefix_ = self.valuelist_nsprefix_ + ':' if (UseCapturedNS_ and self.valuelist_nsprefix_) else ''
             showIndent(outfile, level, pretty_print)
-            outfile.write('<%sdecimal02>%s</%sdecimal02>%s' % (namespaceprefix_ , self.gds_format_decimal(self.decimal02, input_name='decimal02'), namespaceprefix_ , eol_))
-        if self.decimal03 is not None:
-            namespaceprefix_ = self.decimal03_nsprefix_ + ':' if (UseCapturedNS_ and self.decimal03_nsprefix_) else ''
-            showIndent(outfile, level, pretty_print)
-            outfile.write('<%sdecimal03>%s</%sdecimal03>%s' % (namespaceprefix_ , self.gds_format_decimal(self.decimal03, input_name='decimal03'), namespaceprefix_ , eol_))
+            outfile.write('<%svaluelist>%s</%svaluelist>%s' % (namespaceprefix_ , self.gds_format_decimal_list(valuelist_, input_name='valuelist'), namespaceprefix_ , eol_))
     def build(self, node, gds_collector_=None):
         self.gds_collector_ = gds_collector_
         if SaveElementTreeNode:
@@ -1082,29 +1093,28 @@ class containerType(GeneratedsSuper):
     def buildAttributes(self, node, attrs, already_processed):
         pass
     def buildChildren(self, child_, node, nodeName_, fromsubclass_=False, gds_collector_=None):
-        if nodeName_ == 'decimal01' and child_.text:
+        if nodeName_ == 'value' and child_.text:
             sval_ = child_.text
-            fval_ = self.gds_parse_decimal(sval_, node, 'decimal01')
-            fval_ = self.gds_validate_decimal(fval_, node, 'decimal01')
-            self.decimal01 = fval_
-            self.decimal01_nsprefix_ = child_.prefix
-        elif nodeName_ == 'decimal02' and child_.text:
-            sval_ = child_.text
-            fval_ = self.gds_parse_decimal(sval_, node, 'decimal02')
-            fval_ = self.gds_validate_decimal(fval_, node, 'decimal02')
-            self.decimal02 = fval_
-            self.decimal02_nsprefix_ = child_.prefix
-        elif nodeName_ == 'decimal03' and child_.text:
-            sval_ = child_.text
-            fval_ = self.gds_parse_decimal(sval_, node, 'decimal03')
-            fval_ = self.gds_validate_decimal(fval_, node, 'decimal03')
-            self.decimal03 = fval_
-            self.decimal03_nsprefix_ = child_.prefix
-# end class containerType
+            fval_ = self.gds_parse_decimal(sval_, node, 'value')
+            fval_ = self.gds_validate_decimal(fval_, node, 'value')
+            self.value.append(fval_)
+            self.value_nsprefix_ = child_.prefix
+        elif nodeName_ == 'valuelist':
+            mo_ = PRESERVE_CDATA_TAGS_PAT.search(etree_.tostring(child_).strip().decode())
+            if mo_ is None:
+                value_ = ''
+            else:
+                value_ = mo_.group(1)
+            value_ = self.gds_validate_decimal_list(value_, node, 'valuelist')
+            self.valuelist.append(value_)
+            self.valuelist_nsprefix_ = child_.prefix
+            # validate type valuesListType
+            self.validate_valuesListType(self.valuelist[-1])
+# end class valuesType
 
 
 GDSClassesMapping = {
-    'container': containerType,
+    'values': valuesType,
 }
 
 
@@ -1151,8 +1161,8 @@ def parse(inFileName, silence=False, print_warnings=True):
     rootNode = doc.getroot()
     rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
-        rootTag = 'containerType'
-        rootClass = containerType
+        rootTag = 'valuesType'
+        rootClass = valuesType
     rootObj = rootClass.factory()
     rootObj.build(rootNode, gds_collector_=gds_collector)
     CapturedNsmap_, namespacedefs = get_required_ns_prefix_defs(rootNode)
@@ -1183,8 +1193,8 @@ def parseEtree(inFileName, silence=False, print_warnings=True,
     rootNode = doc.getroot()
     rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
-        rootTag = 'containerType'
-        rootClass = containerType
+        rootTag = 'valuesType'
+        rootClass = valuesType
     rootObj = rootClass.factory()
     rootObj.build(rootNode, gds_collector_=gds_collector)
     # Enable Python to collect the space used by the DOM.
@@ -1226,8 +1236,8 @@ def parseString(inString, silence=False, print_warnings=True):
     gds_collector = GdsCollector_()
     rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
-        rootTag = 'containerType'
-        rootClass = containerType
+        rootTag = 'valuesType'
+        rootClass = valuesType
     rootObj = rootClass.factory()
     rootObj.build(rootNode, gds_collector_=gds_collector)
     if not SaveElementTreeNode:
@@ -1254,8 +1264,8 @@ def parseLiteral(inFileName, silence=False, print_warnings=True):
     rootNode = doc.getroot()
     rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
-        rootTag = 'containerType'
-        rootClass = containerType
+        rootTag = 'valuesType'
+        rootClass = valuesType
     rootObj = rootClass.factory()
     rootObj.build(rootNode, gds_collector_=gds_collector)
     # Enable Python to collect the space used by the DOM.
@@ -1294,5 +1304,5 @@ RenameMappings_ = {
 }
 
 __all__ = [
-    "containerType"
+    "valuesType"
 ]
