@@ -68,12 +68,19 @@ SaveElementTreeNode = True
 
 
 class simpleTypeTestsTypeSub(supermod.simpleTypeTestsType):
-    def __init__(self, simpleTypeTest=None, **kwargs_):
-        super(simpleTypeTestsTypeSub, self).__init__(simpleTypeTest,  **kwargs_)
+    def __init__(self, simpleTypeTest=None, simpleContentTest=None, **kwargs_):
+        super(simpleTypeTestsTypeSub, self).__init__(simpleTypeTest, simpleContentTest,  **kwargs_)
 supermod.simpleTypeTestsType.subclass = simpleTypeTestsTypeSub
 # end class simpleTypeTestsTypeSub
 
 
+class simpleContentTypeSub(supermod.simpleContentType):
+    def __init__(self, lang=None, identifier=None, valueOf_=None, **kwargs_):
+        super(simpleContentTypeSub, self).__init__(lang, identifier, valueOf_,  **kwargs_)
+supermod.simpleContentType.subclass = simpleContentTypeSub
+# end class simpleContentTypeSub
+
+
 class simpleTypeTestDefsSub(supermod.simpleTypeTestDefs):
     def __init__(self, datetime1=None, datetime2=None, datetime3=None, datetime4=None, datetime5=None, integerVal1=None, integerVal2=None, stringVal1=None, stringVal2=None, booleanVal1=None, booleanVal2=None, decimalVal1=None, decimalVal2=None, doubleVal1=None, doubleVal2=None, floatVal1=None, floatVal2=None, dateVal1=None, dateVal2=None, dateTimeVal1=None, dateTimeVal2=None, **kwargs_):
         super(simpleTypeTestDefsSub, self).__init__(datetime1, datetime2, datetime3, datetime4, datetime5, integerVal1, integerVal2, stringVal1, stringVal2, booleanVal1, booleanVal2, decimalVal1, decimalVal2, doubleVal1, doubleVal2, floatVal1, floatVal2, dateVal1, dateVal2, dateTimeVal1, dateTimeVal2,  **kwargs_)
