@@ -960,10 +960,11 @@ class simpleTypeTestsType(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
         MemberSpec_('simpleTypeTest', 'simpleTypeTestDefs', 1, 0, {'maxOccurs': 'unbounded', 'name': 'simpleTypeTest', 'type': 'simpleTypeTestDefs'}, None),
+        MemberSpec_('simpleContentTest', 'simpleContentType', 0, 0, {'default': 'null_string', 'name': 'simpleContentTest', 'type': 'simpleContentType'}, None),
     ]
     subclass = None
     superclass = None
-    def __init__(self, simpleTypeTest=None, gds_collector_=None, **kwargs_):
+    def __init__(self, simpleTypeTest=None, simpleContentTest=None, gds_collector_=None, **kwargs_):
         self.gds_collector_ = gds_collector_
         self.gds_elementtree_node_ = None
         self.original_tagname_ = None
@@ -974,6 +975,11 @@ class simpleTypeTestsType(GeneratedsSuper):
         else:
             self.simpleTypeTest = simpleTypeTest
         self.simpleTypeTest_nsprefix_ = None
+        if simpleContentTest is None:
+            self.simpleContentTest = globals()['simpleContentType']('null_string')
+        else:
+            self.simpleContentTest = simpleContentTest
+        self.simpleContentTest_nsprefix_ = None
     def factory(*args_, **kwargs_):
         if CurrentSubclassModule_ is not None:
             subclass = getSubclassFromModule_(
@@ -999,9 +1005,14 @@ class simpleTypeTestsType(GeneratedsSuper):
         self.simpleTypeTest.insert(index, value)
     def replace_simpleTypeTest_at(self, index, value):
         self.simpleTypeTest[index] = value
+    def get_simpleContentTest(self):
+        return self.simpleContentTest
+    def set_simpleContentTest(self, simpleContentTest):
+        self.simpleContentTest = simpleContentTest
     def hasContent_(self):
         if (
-            self.simpleTypeTest
+            self.simpleTypeTest or
+            self.simpleContentTest is not None
         ):
             return True
         else:
@@ -1039,6 +1050,9 @@ class simpleTypeTestsType(GeneratedsSuper):
         for simpleTypeTest_ in self.simpleTypeTest:
             namespaceprefix_ = self.simpleTypeTest_nsprefix_ + ':' if (UseCapturedNS_ and self.simpleTypeTest_nsprefix_) else ''
             simpleTypeTest_.export(outfile, level, namespaceprefix_, namespacedef_='', name_='simpleTypeTest', pretty_print=pretty_print)
+        if self.simpleContentTest is not None:
+            namespaceprefix_ = self.simpleContentTest_nsprefix_ + ':' if (UseCapturedNS_ and self.simpleContentTest_nsprefix_) else ''
+            self.simpleContentTest.export(outfile, level, namespaceprefix_, namespacedef_='', name_='simpleContentTest', pretty_print=pretty_print)
     def build(self, node, gds_collector_=None):
         self.gds_collector_ = gds_collector_
         if SaveElementTreeNode:
@@ -1058,9 +1072,124 @@ class simpleTypeTestsType(GeneratedsSuper):
             obj_.build(child_, gds_collector_=gds_collector_)
             self.simpleTypeTest.append(obj_)
             obj_.original_tagname_ = 'simpleTypeTest'
+        elif nodeName_ == 'simpleContentTest':
+            obj_ = simpleContentType.factory(parent_object_=self)
+            obj_.build(child_, gds_collector_=gds_collector_)
+            self.simpleContentTest = obj_
+            obj_.original_tagname_ = 'simpleContentTest'
 # end class simpleTypeTestsType
 
 
+class simpleContentType(GeneratedsSuper):
+    __hash__ = GeneratedsSuper.__hash__
+    member_data_items_ = [
+        MemberSpec_('lang', 'xs:normalizedString', 0, 1, {'use': 'optional'}),
+        MemberSpec_('identifier', 'xs:normalizedString', 0, 1, {'use': 'optional'}),
+        MemberSpec_('valueOf_', 'xs:normalizedString', 0),
+    ]
+    subclass = None
+    superclass = None
+    def __init__(self, lang=None, identifier=None, valueOf_=None, gds_collector_=None, **kwargs_):
+        self.gds_collector_ = gds_collector_
+        self.gds_elementtree_node_ = None
+        self.original_tagname_ = None
+        self.parent_object_ = kwargs_.get('parent_object_')
+        self.ns_prefix_ = None
+        self.lang = _cast(None, lang)
+        self.lang_nsprefix_ = None
+        self.identifier = _cast(None, identifier)
+        self.identifier_nsprefix_ = None
+        self.valueOf_ = valueOf_
+    def factory(*args_, **kwargs_):
+        if CurrentSubclassModule_ is not None:
+            subclass = getSubclassFromModule_(
+                CurrentSubclassModule_, simpleContentType)
+            if subclass is not None:
+                return subclass(*args_, **kwargs_)
+        if simpleContentType.subclass:
+            return simpleContentType.subclass(*args_, **kwargs_)
+        else:
+            return simpleContentType(*args_, **kwargs_)
+    factory = staticmethod(factory)
+    def get_ns_prefix_(self):
+        return self.ns_prefix_
+    def set_ns_prefix_(self, ns_prefix):
+        self.ns_prefix_ = ns_prefix
+    def get_lang(self):
+        return self.lang
+    def set_lang(self, lang):
+        self.lang = lang
+    def get_identifier(self):
+        return self.identifier
+    def set_identifier(self, identifier):
+        self.identifier = identifier
+    def get_valueOf_(self): return self.valueOf_
+    def set_valueOf_(self, valueOf_): self.valueOf_ = valueOf_
+    def hasContent_(self):
+        if (
+            (1 if type(self.valueOf_) in [int,float] else self.valueOf_)
+        ):
+            return True
+        else:
+            return False
+    def export(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='simpleContentType', pretty_print=True):
+        imported_ns_def_ = GenerateDSNamespaceDefs_.get('simpleContentType')
+        if imported_ns_def_ is not None:
+            namespacedef_ = imported_ns_def_
+        if pretty_print:
+            eol_ = '\n'
+        else:
+            eol_ = ''
+        if self.original_tagname_ is not None and name_ == 'simpleContentType':
+            name_ = self.original_tagname_
+        if UseCapturedNS_ and self.ns_prefix_:
+            namespaceprefix_ = self.ns_prefix_ + ':'
+        showIndent(outfile, level, pretty_print)
+        outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
+        already_processed = set()
+        self.exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='simpleContentType')
+        if self.hasContent_():
+            outfile.write('>')
+            outfile.write(self.convert_unicode(self.valueOf_))
+            self.exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='simpleContentType', pretty_print=pretty_print)
+            outfile.write('</%s%s>%s' % (namespaceprefix_, name_, eol_))
+        else:
+            outfile.write('/>%s' % (eol_, ))
+    def exportAttributes(self, outfile, level, already_processed, namespaceprefix_='', name_='simpleContentType'):
+        if self.lang is not None and 'lang' not in already_processed:
+            already_processed.add('lang')
+            outfile.write(' lang=%s' % (self.gds_encode(self.gds_format_string(quote_attrib(self.lang), input_name='lang')), ))
+        if self.identifier is not None and 'identifier' not in already_processed:
+            already_processed.add('identifier')
+            outfile.write(' identifier=%s' % (self.gds_encode(self.gds_format_string(quote_attrib(self.identifier), input_name='identifier')), ))
+    def exportChildren(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='simpleContentType', fromsubclass_=False, pretty_print=True):
+        pass
+    def build(self, node, gds_collector_=None):
+        self.gds_collector_ = gds_collector_
+        if SaveElementTreeNode:
+            self.gds_elementtree_node_ = node
+        already_processed = set()
+        self.ns_prefix_ = node.prefix
+        self.buildAttributes(node, node.attrib, already_processed)
+        self.valueOf_ = get_all_text_(node)
+        for child in node:
+            nodeName_ = Tag_pattern_.match(child.tag).groups()[-1]
+            self.buildChildren(child, node, nodeName_, gds_collector_=gds_collector_)
+        return self
+    def buildAttributes(self, node, attrs, already_processed):
+        value = find_attr_value_('lang', node)
+        if value is not None and 'lang' not in already_processed:
+            already_processed.add('lang')
+            self.lang = value
+        value = find_attr_value_('identifier', node)
+        if value is not None and 'identifier' not in already_processed:
+            already_processed.add('identifier')
+            self.identifier = value
+    def buildChildren(self, child_, node, nodeName_, fromsubclass_=False, gds_collector_=None):
+        pass
+# end class simpleContentType
+
+
 class simpleTypeTestDefs(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
@@ -1786,6 +1915,7 @@ RenameMappings_ = {
 }
 
 __all__ = [
+    "simpleContentType",
     "simpleTypeTestDefs",
     "simpleTypeTestsType"
 ]
